/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

/**
 * The class <code>AccessFactory</code> generates
 * AccessObjects from several start points.
 * @author forge-cl
 */

public final class AccessFactory {
	/**
	 * This constructor prevents intiatiations of this class.
	 *
	 */
	private AccessFactory() {
	}

	/**
	 * The method <code>newInstance</code> create a new instance of a class,
	 * using a constructor without arguments.
	 *
	 * @param aClassName
	 *            the name of the class, which should be instantiated
	 * @return a instance of AccessObject for future access.
	 * @throws TestExtensionException
	 *             when errors occures during intantiation
	 */
	public static AccessObject newInstance(final String aClassName)
			throws TestExtensionException {
		return newInstance(aClassName, new Class[] {});
	}

	/**
	 * The method <code>newInstance</code> create a new instance of a class,
	 * using a constructor which suites to the arguments.
	 * @param aClassName the name of the class, which should be instantiated
	 * @param aParameters the parameter for the constructor
	 * @return a instance of AccessObject for future access
	 * @throws TestExtensionException when errors occures during instantiation
	 */
	public static AccessObject newInstance(final String aClassName,
			final Object[] aParameters) throws TestExtensionException {
		return new AccessObjectImpl(aClassName, aParameters);
	}
}
