/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

import java.lang.reflect.Field;

/**
 * The class <code>AccessFieldImpl</code> declares the required
 * methods for accessing a non public field.
 *
 * @author forge-cl
 *
 */
class AccessFieldImpl implements AccessField {

	/**
	 * The file <code>inspectedObject</code> contains
	 * the concret instance of the class.
	 */
	private Object inspectedObject;
	/**
	 * The field <code>selectedField</code> contains
	 * the field, which should manipulate.
	 */
	private Field selectedField;

	/**
	 *
	 */
	private AccessibilityManipulator manipulator;
	/**
	 * The constructor take over the required data and
	 * initialised the object.
	 * @param theInspectedClass the class which will inspected.
	 * @param theInspectedObject the object, which is an instance
	 * 	of the class.
	 * @param theSelectedField the field, which contains to the
	 * class and the object.
	 */
	public AccessFieldImpl(final Class theInspectedClass,
			final Object theInspectedObject, final Field theSelectedField) {
			inspectedObject = theInspectedObject;
			selectedField = theSelectedField;
			selectAccessibilityManipulator();
	}

	/**
	 * The method <code>selectAccessibilityManipulator</code>
	 * select a behavior for manipulation of the
	 * SecurityManager.
	 */
	private void selectAccessibilityManipulator() {
		manipulator = AccessibilityManipulator.selectManipulator(selectedField);
	}

	/**
	 * The method <code>getValue</code> give the value of the selected field.
	 *
	 * @return the value of the selected field.
	 * @throws TestExtensionException
	 *             shows, that an error occures during field access.
	 */
	public Object getValue() throws TestExtensionException {
		Object aValue = null;
		manipulator.before();
		try {
			aValue = selectedField.get(inspectedObject);
		} catch (IllegalArgumentException e) {
			throw new TestExtensionException(e);
		} catch (IllegalAccessException e) {
			throw new TestExtensionException(e);
		} finally {
			manipulator.after();
		}
		return aValue;
	}

	/**
	 * The method <code>setValue</code> set the selected field to the given
	 * value.
	 *
	 * @param aNewValue
	 *            the value, which should the selected field contains after this
	 *            method call.
	 * @throws TestExtensionException
	 *             if the dstValue does not suite to the field or any other
	 *             exception occures.
	 */
	public void setValue(final Object aNewValue) throws TestExtensionException {
		manipulator.before();
		try {
			selectedField.set(inspectedObject, aNewValue);
		} catch (IllegalArgumentException e) {
			throw new TestExtensionException(e);
		} catch (IllegalAccessException e) {
			throw new TestExtensionException(e);
		} finally {
			manipulator.after();
		}

	}

}
