/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

/**
 * The <code>AccessMethod</code> describes the interface, for accessing a
 * Method.
 *
 * @author forge-cl
 *
 */
public interface AccessMethod {

	/**
	 * The method <code>call</code> the definied methods with the spezified
	 * arguments.
	 *
	 * @param args
	 *            the args for the method call.
	 * @return the return value of the method call
	 * @throws TestExtensionException
	 *             if no method, which suites to the args, was found or any
	 *             other error occures.
	 */
	Object call(final Object[] args) throws TestExtensionException;

	/**
	 * The method <code>call</code> the definied methods with no arguments.
	 *
	 * @return the return value of the method call
	 * @throws TestExtensionException
	 *             if no method, which suites to the args, was found or any
	 *             other error occures.
	 */
	Object call() throws TestExtensionException;

	/**
	 * The method <code>call</code> the definied methods with the spezified
	 * arguments.
	 *
	 * @param arg
	 *            one parameter for the method call.
	 * @return the return value of the method call
	 * @throws TestExtensionException
	 *             if no method, which suites to the args, was found or any
	 *             other error occures.
	 */
	Object call(final Object arg) throws TestExtensionException;

	/**
	 * The method <code>call</code> the definied methods with the spezified
	 * arguments.
	 *
	 * @param arg1
	 *            first parameter for the method call.
	 * @param arg2
	 *            second parameter for the method call.
	 * @return the return value of the method call
	 * @throws TestExtensionException
	 *             if no method, which suites to the args, was found or any
	 *             other error occures.
	 */
	Object call(final Object arg1, final Object arg2)
			throws TestExtensionException;

	/**
	 * The method <code>call</code> the definied methods with the spezified
	 * arguments.
	 * @param arg1
	 *            first parameter for the method call.
	 * @param arg2
	 *            second parameter for the method call.
	 * @param arg3
	 *            third parameter for the method call.
	 *
	 * @return the return value of the method call
	 * @throws TestExtensionException
	 *             if no method, which suites to the args, was found or any
	 *             other error occures.
	 */
	Object call(final Object arg1, final Object arg2, final Object arg3)
			throws TestExtensionException;
}
