/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

/**
 * The interface <code>AccessObject</code> declares the methods
 * to access non public fields and methods. The implementation
 * of the AccessObject should enclose all the nessecary things.
 * @author forge-cl
 *
 */
public interface AccessObject {

	/**
	 * The methode <code>getField</code> select a field
	 * for manipulation.
	 * @param fieldName the name of the wished field.
	 * @return an instance of AccessField
	 * @throws TestExtensionException the exception shows an
	 * error, when preparing the access to the field.
	 */
	AccessField getField(String fieldName) throws TestExtensionException;

	/**
	 * The method <code>getMethod</code> provide access to
	 * a by name called method. If there exists several methods
	 * with the same name, all methods were accessed by this method.
	 * @param methodName the name of the method.
	 * @return an object, which provide access to the method.
	 * @throws TestExtensionException the exception shows an
	 * error, when preparing the access to the method, for instance
	 * when no method was found.
	 */
	AccessMethod getMethod(String methodName) throws TestExtensionException;

	/**
	 * The method <code>newInnerInstance</code> create a instance of an
	 * inner class from the current object.
	 * @param innerClassname The name of the inner class without the prefix for
	 * 	the outer class.
	 * @return a new instance of an inner class of the current object.
	 * @throws TestExtensionException shows any error.
	 */
	AccessObject newInnerInstance(String innerClassname)
		throws TestExtensionException;

	/**
	 * The method <code>newInnerInstance</code> create a instance of an inner
	 * class from the current object.
	 *
	 * @param innerClassname
	 *            The name of the inner class without the prefix for the outer
	 *            class.
	 * @param args
	 *            the arguments for the constructor.
	 * @return a new instance of an inner class of the current object.
	 * @throws TestExtensionException
	 *             shows any error.
	 */
	AccessObject newInnerInstance(String innerClassname, Object[] args)
		throws TestExtensionException;

}
