/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

import java.lang.reflect.AccessibleObject;

/**
 * The interface declares methodes for manipulating the SecurityManger.
 * @author forge-cl
 */
abstract class AccessibilityManipulator {
	/**
	 * The method <code>befor</code> must be called before accessing a non
	 * public field.
	 */
	public abstract void before();

	/**
	 * The method <code>after</code> must be called after accessing a non
	 * public field.
	 *
	 */
	public abstract void after();

	/**
	 * The method <code>selectManipulator</code> generate a
	 * AccessibilityManipulator, which suites to the member.
	 *
	 * @param forMember
	 *            The member for the AccessibilityManipulator
	 * @return the required AccessibilityManipulator
	 */
	public static AccessibilityManipulator selectManipulator(
			final AccessibleObject forMember) {
		AccessibilityManipulator manipulator;
		if (forMember.isAccessible()) {
			manipulator = new AccessibilityManipulator() {
				public void after() {
				}

				public void before() {
				}
			};
		} else {
			manipulator = new AccessibilityManipulator() {
				public void after() {
					forMember.setAccessible(false);
				}

				public void before() {
					forMember.setAccessible(true);
				}

			};
		}
		return manipulator;
	}
}
