/*
This project provide access to non public fields
and methods as help for writing tests.
Copyright (C) 2007  Christof Lehmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package net.sf.testextensions;

/**
 * The <code>AccessibleObjectContainer</code> declares a usefull
 * method, which would be used by subclasses.
 * @author forge-cl
 *
 */
class AccessibleObjectContainer {

	/**
	 * The field <code>parameterClasses</code> remember the types
	 * of the callable method or constructor.
	 */
	private Class < ? > [] parameterClasses;

	/**
	 * The constructor initialize the field argumentClasses.
	 * @param theParameterClasses the types of the method invocation
	 */
	protected AccessibleObjectContainer(
			final Class < ? > [] theParameterClasses) {
		parameterClasses = theParameterClasses;
	}

	/**
	 * The method <code>suitesToArgs</code> check, if the types
	 * of the arguments for a method call suites to the accepted
	 * types.
	 * @param args the arguments for the method call
	 * @return true if the arguments suites to the method declaration
	 */
	public boolean suitesToArgs(final Object[] args) {
		boolean flag = parameterClasses != null
			&&
			parameterClasses .length == args .length;
		for (int i = 0; i < parameterClasses.length && flag; i++) {
			Object curParameter = args[i];
			Class curParamClass = parameterClasses[i];
			flag = isInstanceOf(curParameter, curParamClass);
		}
		return flag;
   }

	/**
	 * The method <code>isInstanceOf</code> checks, if a object is an instance
	 * of a class. Its also works with primitive.
	 *
	 * @param aObject
	 *            the object, which should be an instanceOf
	 * @param aClass
	 *            the object should be an instance of this class.
	 * @return true wenn aClass.isInstance(aObject) or its aquivalent
	 *
	 */
	private boolean isInstanceOf(final Object aObject, final Class aClass) {
		return aClass.isInstance(aObject)
				|| (getAequivalent(aClass).isInstance(aObject));
	}

	/**
	 * The method <code>getQequivalent</code> returns the non primitive
	 * representation of a primitive.
	 *
	 * @param aClass
	 *            a primitive Class
	 * @return the non primitive or the same class
	 */
	private Class getAequivalent(final Class aClass) {
		if (aClass.isPrimitive()) {
			String theName = aClass.getName();
			if (theName.equals("int")) {
				return Integer.class;
			} else if (theName.equals("double")) {
				return Double.class;
			} else if (theName.equals("short")) {
				return Short.class;
			} else if (theName.equals("char")) {
				return Character.class;
			} else if (theName.equals("long")) {
				return Long.class;
			} else if (theName.equals("boolean")) {
				return Boolean.class;
			} else if (theName.equals("byte")) {
				return Byte.class;
			} else {
				return aClass;
			}
		} else {
			return aClass;
		}
	}


}
